bayespy.inference.vmp.nodes.gaussian.GaussianDistribution.compute_mask_to_parent
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianDistribution.compute_mask_to_parent